@@ -40,7 +40,7 @@ version="0.82c"
 txt_version=$"Version "$version
 
 TEXTDOMAINDIR=/usr/share/locale
-TEXTDOMAIN=unplugdrive.sh
+TEXTDOMAIN=unplugdrive
 
 decorations="--undecorated"
 centred=""
